==> libreoffice-4.1.1.2.tar.xz: libreoffice-4.1.1.2/shell/inc/internal/resource.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#ifndef RESOURCE_H_INCLUDED
#define RESOURCE_H_INCLUDED

#define MANIFEST_RESOURCE_ID               2
#define IDD_PROPPAGE_STATISTICS          101
#define IDD_PROPPAGE_SUMMARY             102
#define IDB_PROPERTY_IMAGES         103
#define IDC_TITLE                       1000
#define IDC_SUBJECT                     1001
#define IDC_AUTHOR                      1002
#define IDC_CREATOR                     1003
#define IDC_LANGUAGE                    1004
#define IDC_COMMENTS                    1005
#define IDC_KEYWORDS                    1006
#define IDC_EXTENDED                    1009
#define IDC_DLGSIMPLE                   1012
#define IDC_STATISTICSLIST              1013

#define IDS_TITLE                       1014
#define IDS_SUBJECT                     1015
#define IDS_AUTHOR                      1016
#define IDS_KEYWORDS                    1017
#define IDS_COMMENTS                    1018
#define IDS_PAGES                       1019
#define IDS_TABLES                      1020
#define IDS_GRAPHICS                    1021
#define IDS_OLE_OBJECTS                 1022
#define IDS_PARAGRAPHS                  1023
#define IDS_WORDS                       1024
#define IDS_CHARACTERS                  1025
#define IDS_ROWS                        1026
#define IDS_ORIGIN                      1027
#define IDS_VERSION                     1028
#define IDS_SHEETS                      1029
#define IDS_CELLS                       1030
#define IDS_STATISTICS                  1031
#define IDS_PROPERTY                    1032
#define IDS_PROPERTY_VALUE              1033
#define IDS_PROPPAGE_SUMMARY_TITLE      1034
#define IDS_PROPPAGE_STATISTICS_TITLE   1035
#define IDS_TITLE_COLON                 1036
#define IDS_SUBJECT_COLON               1037
#define IDS_AUTHOR_COLON                1038
#define IDS_OBJECTS                     1039
#define IDS_DOCUMENT_STATISTIC          1040
#define IDS_MODIFIED                    1041
#define IDS_DOCUMENT_NUMBER             1042
#define IDS_EDITING_TIME                1043
#define IDS_DESCRIPTION                 1044
#define IDS_COMMENTS_COLON              1045
#define IDS_MODIFIED_COLON              1046
#define IDS_SIZE_COLON                  1047
#define IDS_TYPE_COLON                  1048

#define IDP_SIGNET                      2000

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_4.2.8.orig.tar.xz: libreoffice-4.2.8/shell/inc/internal/resource.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#ifndef INCLUDED_SHELL_INC_INTERNAL_RESOURCE_H
#define INCLUDED_SHELL_INC_INTERNAL_RESOURCE_H

#define MANIFEST_RESOURCE_ID               2
#define IDD_PROPPAGE_STATISTICS          101
#define IDD_PROPPAGE_SUMMARY             102
#define IDB_PROPERTY_IMAGES         103
#define IDC_TITLE                       1000
#define IDC_SUBJECT                     1001
#define IDC_AUTHOR                      1002
#define IDC_CREATOR                     1003
#define IDC_LANGUAGE                    1004
#define IDC_COMMENTS                    1005
#define IDC_KEYWORDS                    1006
#define IDC_EXTENDED                    1009
#define IDC_DLGSIMPLE                   1012
#define IDC_STATISTICSLIST              1013

#define IDS_TITLE                       1014
#define IDS_SUBJECT                     1015
#define IDS_AUTHOR                      1016
#define IDS_KEYWORDS                    1017
#define IDS_COMMENTS                    1018
#define IDS_PAGES                       1019
#define IDS_TABLES                      1020
#define IDS_GRAPHICS                    1021
#define IDS_OLE_OBJECTS                 1022
#define IDS_PARAGRAPHS                  1023
#define IDS_WORDS                       1024
#define IDS_CHARACTERS                  1025
#define IDS_ROWS                        1026
#define IDS_ORIGIN                      1027
#define IDS_VERSION                     1028
#define IDS_SHEETS                      1029
#define IDS_CELLS                       1030
#define IDS_STATISTICS                  1031
#define IDS_PROPERTY                    1032
#define IDS_PROPERTY_VALUE              1033
#define IDS_PROPPAGE_SUMMARY_TITLE      1034
#define IDS_PROPPAGE_STATISTICS_TITLE   1035
#define IDS_TITLE_COLON                 1036
#define IDS_SUBJECT_COLON               1037
#define IDS_AUTHOR_COLON                1038
#define IDS_OBJECTS                     1039
#define IDS_DOCUMENT_STATISTIC          1040
#define IDS_MODIFIED                    1041
#define IDS_DOCUMENT_NUMBER             1042
#define IDS_EDITING_TIME                1043
#define IDS_DESCRIPTION                 1044
#define IDS_COMMENTS_COLON              1045
#define IDS_MODIFIED_COLON              1046
#define IDS_SIZE_COLON                  1047
#define IDS_TYPE_COLON                  1048

#define IDP_SIGNET                      2000

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
